@@ -4,7 +4,7 @@ BEGIN{ extends 'DBIx::Class::DeploymentHandler' }
 
 # A wrapper class for DBICDH for use with Galileo
 
-use Mojo::JSON 'j';;
+use Mojo::JSON 'j';
 
 use File::ShareDir qw/dist_dir/;
 use File::Spec;
@@ -121,7 +121,7 @@ HTML
     md        => <<'MARKDOWN',
 ##Welcome to your Galileo CMS site!
 
-> Galileo Galilei was "an Italian physicist, mathematician, astronomer, and philosopher who played a major role in the Scientific Revolution." -- [Wikipedia](https://en.wikipedia.org/wiki/Galileo_Galilei) 
+> Galileo Galilei was "an Italian physicist, mathematician, astronomer, and philosopher who played a major role in the Scientific Revolution." -- [Wikipedia](https://en.wikipedia.org/wiki/Galileo_Galilei)
 
 When he first turned the telescope to face Jupiter, he used modern technology to improve the world around him.
 
@@ -550,12 +550,12 @@ sub create_test_object {
   );
   $dh->do_install;
   $dh->inject_sample_data('admin', 'pass', 'Joe Admin');
-  
+
 
   if ($opts->{test}) {
     require Test::More;
-    Test::More::ok( 
-      $db->resultset('User')->single({name => 'admin'})->check_password('pass'), 
+    Test::More::ok(
+      $db->resultset('User')->single({name => 'admin'})->check_password('pass'),
       'DB user checks out'
     );
     Test::More::ok( $dh->installed_version, 'Found version information' );
