@@ -13,19 +13,20 @@ column author_id => {
 };
 
 unique_column name => { 
-  data_type => 'VARCHAR'
+  data_type => 'VARCHAR',
+  size => 255,
 };
   
 column title => { 
-  data_type => 'VARCHAR'
+  data_type => 'TEXT',
 };
 
 column html => {
-  data_type => 'VARCHAR'
+  data_type => 'TEXT',
 };
 
 column md => { 
-  data_type => 'VARCHAR'
+  data_type => 'TEXT',
 };
 
 belongs_to author => 'Galileo::DB::Schema::Result::User', 'author_id';
